# soulspec

Part of the [ClawSouls](https://clawsouls.ai) AI agent persona ecosystem.

- **Soul Spec**: Open spec for AI agent personas — [docs.clawsouls.ai](https://docs.clawsouls.ai)
- **ClawSouls**: Community registry for soul packages — [clawsouls.ai](https://clawsouls.ai)
- **SoulScan**: Security scanner for AI persona files

Full Python SDK coming soon. For now, use the [npm CLI](https://www.npmjs.com/package/clawsouls).

## Links
- Website: https://clawsouls.ai
- Docs: https://docs.clawsouls.ai
- GitHub: https://github.com/clawsouls
- npm: https://www.npmjs.com/package/clawsouls
